// (C) 2020-2025 GoodData Corporation
import React from "react";
import { FormattedMessage, useIntl } from "react-intl";
import cx from "classnames";
import { messages } from "../locales.js";
import { Button } from "@gooddata/sdk-ui-kit";
function getbuttonIcoStyle(type, buttonsOrientation) {
    if (type === "prev") {
        if (buttonsOrientation === "upDown") {
            return "up";
        }
        return "left";
    }
    if (type === "next") {
        if (buttonsOrientation === "upDown") {
            return "down";
        }
        return "right";
    }
    return undefined;
}
const PagingButton = ({ type, buttonsOrientation, handler, disabled }) => {
    const intl = useIntl();
    const classes = cx("gd-button-link", "gd-button-icon-only", `gd-icon-chevron-${getbuttonIcoStyle(type, buttonsOrientation)}`, "paging-button");
    const buttonLabel = type === "prev" ? intl.formatMessage(messages.previous) : intl.formatMessage(messages.next);
    return (React.createElement(Button, { className: classes, onClick: handler, disabled: disabled, accessibilityConfig: { ariaLabel: buttonLabel } }));
};
/**
 * @internal
 */
export const Paging = (props) => {
    const { page, pagesCount, buttonsOrientation = "upDown", showNextPage, showPrevPage } = props;
    return (React.createElement("div", { className: "paging", "data-testid": "Paging" },
        React.createElement(PagingButton, { type: "prev", buttonsOrientation: buttonsOrientation, handler: showPrevPage, disabled: page === 1 }),
        React.createElement(FormattedMessage, { id: "visualizations.of", tagName: "span", values: {
                page: React.createElement("strong", null, page),
                pagesCount,
            } }),
        React.createElement(PagingButton, { type: "next", buttonsOrientation: buttonsOrientation, handler: showNextPage, disabled: page === pagesCount })));
};
//# sourceMappingURL=Paging.js.map