// (C) 2007-2025 GoodData Corporation
import React from "react";
import cx from "classnames";
import { ZoomAwareOverlay, useMediaQuery, useIsZoomed, ZOOM_THRESHOLD, useIdPrefixed, DialogCloseButton, AutofocusOnMount, } from "@gooddata/sdk-ui-kit";
import { legendDialogAlignPoints, legendMobileDialogAlignPoints } from "./alignPoints.js";
const LegendDialogWrapper = ({ children }) => {
    const isMobile = useMediaQuery("<sm");
    return children(isMobile);
};
const LegendDialogContent = ({ title, onCloseDialog, children, id }) => {
    const isZoomed = useIsZoomed(ZOOM_THRESHOLD);
    const dialogRef = React.useRef(null);
    const handleClose = React.useCallback((e) => {
        e.preventDefault();
        onCloseDialog();
    }, [onCloseDialog]);
    const handleBlur = React.useCallback((e) => {
        // e.relatedTarget is the element receiving focus after the blur
        if (!dialogRef.current || dialogRef.current.contains(e.relatedTarget)) {
            return;
        }
        onCloseDialog();
    }, [onCloseDialog]);
    const className = cx("legend-popup-dialog", "legend-popup-dialog-content", {
        zoomed: isZoomed,
    });
    const titleId = useIdPrefixed("legendDialogContentTitle");
    return (React.createElement("div", { className: className, id: id, role: "dialog", "aria-modal": false, "aria-labelledby": titleId, onBlur: handleBlur, ref: dialogRef },
        React.createElement("div", { className: "legend-header" },
            React.createElement("div", { className: "legend-header-title", id: titleId }, title),
            React.createElement(DialogCloseButton, { className: "s-legend-close legend-close gd-icon-cross gd-button-link gd-button-icon-only", onClose: handleClose })),
        React.createElement(AutofocusOnMount, null,
            React.createElement("div", { className: "legend-content" }, children))));
};
export const LegendDialog = ({ name, children, isOpen, alignTo, onCloseDialog, id, }) => {
    if (!isOpen) {
        return null;
    }
    return (React.createElement(LegendDialogWrapper, null, (isMobile) => {
        return (React.createElement(ZoomAwareOverlay, { alignTo: alignTo, alignPoints: isMobile ? legendMobileDialogAlignPoints : legendDialogAlignPoints, closeOnOutsideClick: !isMobile, onClose: onCloseDialog, className: "kpi-alert-dialog-overlay", ensureVisibility: true, closeOnEscape: true },
            React.createElement(LegendDialogContent, { title: name, onCloseDialog: onCloseDialog, id: id }, children)));
    }));
};
//# sourceMappingURL=LegendDialog.js.map