// (C) 2007-2025 GoodData Corporation
import React, { useState } from "react";
import { Button, Icon } from "@gooddata/sdk-ui-kit";
import cx from "classnames";
import { LegendLabelItem } from "../LegendLabelItem.js";
import { LegendList } from "../LegendList.js";
import { LegendSeries } from "../LegendSeries.js";
import { useIntl } from "react-intl";
const LEGEND_ROW_HEIGHT = 20;
const LEGEND_TOP_BOTTOM_PADDING = 10;
const useCheckOverflow = () => {
    const [isOverflow, setOverFlow] = useState(false);
    const [numOfUsedRow, setNumOfUsedRow] = useState(1);
    const getNumberOfRows = (clientHeight) => {
        return Math.ceil((clientHeight - LEGEND_TOP_BOTTOM_PADDING) / LEGEND_ROW_HEIGHT);
    };
    const checkOverFlow = (element) => {
        if (!element)
            return;
        const { clientHeight, scrollHeight } = element;
        setOverFlow(scrollHeight > clientHeight);
        const numberOfRows = getNumberOfRows(clientHeight);
        setNumOfUsedRow(numberOfRows);
    };
    return [isOverflow, numOfUsedRow, checkOverFlow];
};
export const RowLegendIcoButton = ({ isVisible, isActive, onIconClick, dialogId, triggerId, }) => {
    const { formatMessage } = useIntl();
    const handleClick = React.useCallback((e) => {
        e.stopPropagation();
        e.preventDefault();
        onIconClick();
    }, [onIconClick]);
    if (!isVisible) {
        return null;
    }
    const iconClasses = cx("legend-popup-button legend-popup-icon s-legend-popup-icon", {
        "legend-popup-icon-active": isActive,
    });
    return (React.createElement("div", { className: "legend-popup-button" },
        React.createElement(Button, { onClick: handleClick, className: iconClasses, tabIndex: 0, accessibilityConfig: {
                isExpanded: isActive,
                popupId: dialogId,
                ariaLabel: formatMessage({ id: "properties.legend.more.button" }),
            }, id: triggerId },
            React.createElement("div", { role: "presentation" },
                React.createElement(Icon.LegendMenu, null)))));
};
export const RowLegend = (props) => {
    const { series, maxRowsCount = 1, legendLabel, enableBorderRadius, onDialogIconClick, onLegendItemClick, dialogId, triggerId, isActive = false, } = props;
    const [isOverflow, numOfUsedRow, checkOverFlow] = useCheckOverflow();
    const LEGEND_HEIGHT = maxRowsCount * LEGEND_ROW_HEIGHT + LEGEND_TOP_BOTTOM_PADDING;
    const itemsAlign = numOfUsedRow === 1 ? "flex-end" : "flex-start";
    return (React.createElement("div", { className: "legend-popup-row", style: { maxHeight: LEGEND_HEIGHT } },
        React.createElement(LegendSeries, { onToggleItem: onLegendItemClick, series: series, ref: checkOverFlow, style: {
                justifyContent: itemsAlign,
            }, label: legendLabel, className: "viz-legend static position-row" },
            React.createElement(LegendLabelItem, { label: legendLabel }),
            React.createElement(LegendList, { enableBorderRadius: enableBorderRadius, series: series, onItemClick: onLegendItemClick })),
        React.createElement(RowLegendIcoButton, { isActive: isActive, isVisible: isOverflow, onIconClick: onDialogIconClick, dialogId: dialogId, triggerId: triggerId })));
};
//# sourceMappingURL=RowLegend.js.map